Method: Ably::Realtime::Channels#release

Defined in:
lib/ably/realtime/channels.rb

#release(channel) ⇒ void

This method returns an undefined value.

Detaches the Realtime Channel and releases all associated resources.

Releasing a Realtime Channel is not typically necessary as a channel, once detached, consumes no resources other than the memory footprint of the Realtime Channel object. Release channels to free up resources if required



43
44
45
46
47
# File 'lib/ably/realtime/channels.rb', line 43

def release(channel)
  get(channel).detach do
    @channels.delete(channel)
  end if @channels.has_key?(channel)
end