Module: Ably::Realtime::Models::Shared
- Includes:
- Modules::Conversions
- Included in:
- ErrorInfo, Message, ProtocolMessage
- Defined in:
- lib/ably/realtime/models/shared.rb
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#[](key) ⇒ Object
Provide a normal Hash accessor to the underlying raw message object.
Instance Method Details
#==(other) ⇒ Object
12 13 14 15 |
# File 'lib/ably/realtime/models/shared.rb', line 12 def ==(other) other.kind_of?(self.class) && json == other.json end |
#[](key) ⇒ Object
Provide a normal Hash accessor to the underlying raw message object
8 9 10 |
# File 'lib/ably/realtime/models/shared.rb', line 8 def [](key) json[key] end |