Method: Ably::Realtime::Connection#send_protocol_message
- Defined in:
- lib/ably/realtime/connection.rb
#send_protocol_message(protocol_message) ⇒ void
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
This method returns an undefined value.
Add protocol message to the outgoing message queue and notify the dispatcher that a message is ready to be sent
392 393 394 395 396 397 398 399 400 |
# File 'lib/ably/realtime/connection.rb', line 392 def () () do Ably::Models::ProtocolMessage.new(, logger: logger).tap do || logger.debug { "Connection: Prot msg queued =>: #{message.action} #{message}" } end end end |